SEp_from_TE.p: Standard Error from Treatment Effect and p-Value
Description
Calculates the pooled standard error using the treatment effect and p-value.
To avoid an infinitive return when p-value = 1, the p-value is automatically adjusted to 0.99999
Usage
SEp_from_TE.p(TE, p, two_tailed = TRUE)
Value
Pooled standard error (e.g. standard error of intervention effect)
Arguments
TE
reported treatment effect
p
reported p-value
two_tailed
whether one-tailed or two-tailed statistics should be calculated
References
Altman D G, Bland J M. How to obtain the confidence interval from a P value BMJ 2011; 343 :d2090 doi:10.1136/bmj.d2090
Cochrane Handbook